@@ -21,5 +21,13 @@ class Mysql:
         self._cursor.execute(sql, args)
         self._connect.commit()
 
+    def insert(self, sql, args=None):
+        self.ping()
+        self._cursor.execute(sql, args)
+        id = self._cursor.lastrowid
+        self._connect.commit()
+
+        return id
+
     def __del__(self):
         self._connect.close()
